@@ -3,15 +3,10 @@ from jovian.utils.credentials import get_api_key, get_guest_key, read_api_url, r
 from jovian.utils.error import ApiError
 from jovian.utils.logger import log
 from jovian.utils.request import get, pretty
-from jovian.utils.misc import urljoin
+from jovian.utils.shared import _u, _v
 from jovian.utils.api import post_slack_message
 
 
-def _u(path):
-    """Make a URL from the path"""
-    return urljoin(read_api_url(), path)
-
-
 def _h():
     """Create a header to provide library metadata"""
     return {"Authorization": "Bearer " + get_api_key(),
@@ -22,13 +17,6 @@ def _h():
             "x-jovian-org": read_org_id()}
 
 
-def _v(version):
-    """Create version query parameter string"""
-    if version is not None:
-        return "?gist_version=" + str(version)
-    return ""
-
-
 def add_slack():
     """prints instructions for connecting Slack, if Slack connection is not already present.
     if Slack is already connected, prints details about the workspace and the channel"""
